@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2021-2022 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2021-2023 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,10 +19,10 @@ prefix="/usr/local"
 
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
+if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/local/pobj/kea-2.2.0-postgresql/kea-2.2.0/src/bin/admin/admin-utils.sh"
+    . "/local/pobj/kea-2.4.0-postgresql/kea-2.4.0/src/bin/admin/admin-utils.sh"
 fi
 
 VERSION=$(pgsql_version "$@")
@@ -36,8 +36,10 @@ fi
 psql "$@" >/dev/null <<EOF
 START TRANSACTION;
 
--- This starts schema update to 8.0. It adds a few missing elements for CB and
--- functions for kea-admin's lease-dump and lease-upload commands.
+-- This line starts the schema upgrade to version 8.0.
+
+-- Adds a few missing elements for CB and functions for kea-admin's lease-dump
+-- and lease-upload commands.
 
 -- -----------------------------------------------------------------------
 -- Extend the table holding DHCPv4 option definitions with a nullable
@@ -508,6 +510,8 @@ END
 UPDATE schema_version
     SET version = '8', minor = '0';
 
+-- This line concludes the schema upgrade to version 8.0.
+
 -- Commit the script transaction.
 COMMIT;
 
