@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2022 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2022-2023 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,10 +19,10 @@ prefix="/usr/local"
 
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
+if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/usr/ports/pobj/kea-2.2.0-postgresql/kea-2.2.0/src/bin/admin/admin-utils.sh"
+    . "/usr/obj/ports/kea-2.4.0-postgresql/kea-2.4.0/src/bin/admin/admin-utils.sh"
 fi
 
 VERSION=$(pgsql_version "$@")
@@ -36,7 +36,7 @@ fi
 psql "$@" >/dev/null <<EOF
 START TRANSACTION;
 
--- This line starts the schema upgrade to version 13.
+-- This line starts the schema upgrade to version 13.0.
 
 -- JSON functions --
 
@@ -673,7 +673,7 @@ CREATE UNIQUE INDEX key_dhcp6_identifier_subnet_id ON hosts
 UPDATE schema_version
     SET version = '13', minor = '0';
 
--- This line concludes the schema upgrade to version 13.
+-- This line concludes the schema upgrade to version 13.0.
 
 -- Commit the script transaction.
 COMMIT;
